{% extends "jauth_example/base.html" %}

{% load i18n %}
{% load staticfiles %}

{% block body %}

{% if error %}
    <div style="color: red">{{ error }}</div>
{% endif %}

<form method="get" action="https://www.facebook.com/v3.3/dialog/oauth">
    <input type="hidden" name="client_id" value="{{ facebook_app_id }}">
    <input type="hidden" name="redirect_uri" value="{{ facebook_redirect_url }}">
    <input type="hidden" name="state" value="{{ uuid }}">
    <button type="submit">Login with Facebook</button>
</form>

<form method="get" action="https://accounts.google.com/o/oauth2/v2/auth">
    <input type="hidden" name="client_id" value="{{ google_app_id }}">
    <input type="hidden" name="redirect_uri" value="{{ google_redirect_url }}">
    <input type="hidden" name="state" value="{{ uuid }}">
    <input type="hidden" name="scope" value="email profile">
    <input type="hidden" name="response_type" value="code">
    <button type="submit">Login with Google</button>
</form>

{% endblock %}
