# Generated by Django 3.1.3 on 2021-02-03 17:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0002_auto_20191218_0625"),
    ]

    operations = [
        migrations.AlterField(
            model_name="accountkituser",
            name="me",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name="facebookuser",
            name="me",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name="googleuser",
            name="me",
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
