# Generated by Django 4.0.3 on 2022-03-27 01:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0003_auto_20210203_1718"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="accountkituser",
            name="user",
        ),
        migrations.DeleteModel(
            name="AccountKitAccessToken",
        ),
        migrations.DeleteModel(
            name="AccountKitUser",
        ),
    ]
