# Generated by Django 4.0.4 on 2024-10-14 19:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0005_alter_facebookaccesstoken_access_token_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="facebookuser",
            name="ext_user_id",
            field=models.CharField(db_index=True, max_length=256),
        ),
        migrations.AlterField(
            model_name="googleuser",
            name="ext_user_id",
            field=models.CharField(db_index=True, max_length=256),
        ),
    ]
